@@ -21,7 +21,61 @@ from navis import utils
 
 import git
 
-__all__ = ['download_jefferislab_transforms', 'download_saalfeldlab_transforms']
+__all__ = ['download_vfb_transforms', 'download_jefferislab_transforms',
+           'download_jrc_transforms', 'download_jrc_vnc_transforms']
+
+
+def download_vfb_transforms(repos=("VfbBridgingRegistrations"),
+                                   update_existing=True,
+                                   use_ssh=False,
+                                   data_home=None):
+    """Download VirtualFlyBrain.org (VFB) CMTK transforms.
+
+    BridgingRegistrations (~6Mb):
+      - JRCVNC2018U_JRCVNC2018F: JRC2018-VNC-UNISEX-4iso -> JRC2018-VNC-FEMALE-4iso
+      - JRCVNC2018M_JRCVNC2018U: JRC2018_VNC_MALE_4iso -> JRC2018_VNC_UNISEX_4iso
+      - COURT2017VNS_JRCVNC2018F: DrosAdultVNSdomains_Court2017_template_Neuropil_LPS -> JRC2018_VNC_FEMALE_4iso_LPS
+      - COURT2018VNS_JRCVNC2018U: 20x_flyVNCtemplate_Female_symmetric -> JRC2018_VNC_UNISEX_4iso
+
+
+    Parameters
+    ----------
+    repos :             "BridgingRegistrations" list thereof
+                        Which registrations to download. These are Github
+                        repositories (e.g. ``VirtualFlyBrain/VfbBridgingRegistrations``)
+                        which will be cloned into ``~/flybrain-data/``.
+    update_existing :   bool
+                        If True, already downloaded transforms will be updated.
+                        If False, these will be skipped.
+    use_ssh :           bool
+                        If True, will use SSH to clone the Github repositories
+                        containing the VFB registrations. See
+                        `here <https://docs.github.com/en/free-pro-team@latest
+                        /github/authenticating-to-github/connecting-to-github-
+                        with-sshhttps://docs.github.com/en/free-pro-team@latest
+                        /github/authenticating-to-github/connecting-to-
+                        github-with-ssh>`_ for an explanation on how to generate
+                        and configure SSH access to Github.
+    data_home :         str
+                        Directory to download files to. If not specified, it
+                        tries to read from the ``FLYBRAINS_DATA`` environment
+                        variable and defaults to ``~/flybrain-data``.
+
+    See Also
+    --------
+    :func:`~flybrains.update_transforms``
+                Use to update already downloaded transforms.
+
+    """
+    data_home = get_data_home(data_home)
+    repos = utils.make_iterable(repos)
+
+    print(f'Downloading VFB transforms into {data_home}')
+    for repo in tqdm(repos, desc='Repos', leave=False):
+        download_reg_repo(f'VirtualFlyBrain/{repo}',
+                          use_ssh=use_ssh,
+                          data_home=data_home,
+                          update_existing=update_existing)
 
 
 def download_jefferislab_transforms(repos=("BridgingRegistrations",
@@ -182,14 +236,17 @@ def download_reg_repo(repo: str, data_home=None, use_ssh=False, update_existing=
         git.Repo.clone_from(url, clone_to, progress=update_pbar)
 
 
-def download_saalfeldlab_transforms(data_home=None, skip_existing=True):
-    """Download the h5 transforms from the Saalfeld lab.
+def download_jrc_transforms(data_home=None, skip_existing=True):
+    """Download H5 transforms between the Janelia Research Campus (JRC) brain templates.
+
+    Generated and kindly provided by the Saalfeld lab (Janelia):
+    https://www.janelia.org/open-science/jrc-2018-brain-templates
 
     Includes:
       - JRC2018 <-> FAFB
       - JRC2018F <-> JFRC2013
       - JRC2018F <-> FCWB
-      - JRC2018F <-> JRCFIB2018F
+      - JRC2018F <-> JRCFIB2018F (hemibrain)
       - JRC2018U <-> JRC2018F
       - JRC2018F <-> JFRC2010
 
@@ -226,7 +283,49 @@ def download_saalfeldlab_transforms(data_home=None, skip_existing=True):
         'JRC2018F_JFRC2010.h5'
       )
 
-    print(f'Downloading Saalfeld lab transforms into {data_home}')
+    print(f'Downloading JRC (Saalfeld lab) brain transforms into {data_home}')
+    for url, file in tqdm(zip(urls, filenames), leave=False,
+                          total=len(urls), desc='Transforms'):
+        dst = os.path.join(data_home, file)
+        if skip_existing and os.path.exists(dst):
+            continue
+        _ = download_from_url(url, dst)
+
+
+def download_jrc_vnc_transforms(data_home=None, skip_existing=True):
+    """Download H5 transforms between the Janelia Research Campus (JRC) VNC templates.
+
+    Generated and kindly provided by the Saalfeld lab (Janelia):
+    https://www.janelia.org/open-science/jrc-2018-brain-templates
+
+    Includes:
+      - JRCVNC2018U <-> JRCVNC2018F (110Mb)
+      - JRCVNC2018U <-> JRCVNC2018M (150Mb)
+
+    Parameters
+    ----------
+    data_home :     str
+                    Directory to download files to. If not specified, it tries to
+                    read from the ``FLYBRAINS_DATA`` environment variable and
+                    defaults to ``~/flybrain-data``.
+    skip_existing : bool
+                    If True, existing files will be skipped. If False, they
+                    will be overwritten.
+
+    """
+    data_home = get_data_home(data_home)
+    urls = (
+        "28909212?private_link=c4589cef9180e1dd4ee1",
+        "28908795?private_link=42ad71eb14e7dd51e81a")
+    urls = [f"https://ndownloader.figshare.com/files/{f}" for f in urls]
+
+    # Note that we are renaming the files upon download!
+    filenames = (
+        'JRCVNC2018U_JRCVNC2018F.h5',  # originally: JRC2018VncU_JRC2018VncF.h5
+        'JRCVNC2018M_JRCVNC2018U.h5',  # originally: JRC2018VncM_JRC2018VncU.h5
+      )
+
+    print(f'Downloading JRC (Saalfeld lab) VNC transforms into {data_home}')
     for url, file in tqdm(zip(urls, filenames), leave=False,
                           total=len(urls), desc='Transforms'):
         dst = os.path.join(data_home, file)
