@@ -28,7 +28,11 @@ from navis.transforms.templates import TemplateBrain
 __all__ = ['FCWB', 'IBN', 'IBNWB', 'IS2', 'JFRC2', 'T1', 'Dmel', 'DsecI',
            'Dsim', 'Dvir', 'JFRC2013', 'JFRC2013DS', 'JRC2018F', 'JRC2018U',
            'JRCFIB2018F', 'JRCFIB2018Fraw', 'JRCFIB2018Fum', 'JRCVNC2018F',
-           'VNCIS1', 'FAFB14', 'register_templates']
+           'JRCVNC2018M',
+           'JRCVNC2018U',
+           'VNCIS1', 'FAFB14', 'FANC', 'DmelL1CNS_Seymour',
+           'COURT2017VNS', 'COURT2018VNS',
+           'register_templates']
 
 # Read in meta data
 fp = os.path.dirname(__file__)
@@ -489,8 +493,9 @@ class _JRC2018F(FlyTemplateBrain):
     ----------
     An unbiased template of the Drosophila brain and ventral nerve cord.
     John A Bogovic, Hideo Otsuna, Larissa Heinrich, Masayoshi Ito,
-    Jennifer Jeter, Geoffrey W Meissner, Aljoscha Nern, Jennifer Colonell,
-    Oz Malkesman, Kei Ito, Stephan Saalfeld bioRxiv 376384; doi: doi:10.1101/376384
+    Jennifer Jeter, Geoffrey Meissner, Aljoscha Nern, Jennifer Colonell,
+    Oz Malkesman, Kei Ito, Stephan Saalfeld.
+    PLOS One; doi: https://doi.org/10.1371/journal.pone.0236495
 
     """
 
@@ -528,8 +533,9 @@ class _JRC2018U(FlyTemplateBrain):
     ----------
     An unbiased template of the Drosophila brain and ventral nerve cord.
     John A Bogovic, Hideo Otsuna, Larissa Heinrich, Masayoshi Ito,
-    Jennifer Jeter, Geoffrey W Meissner, Aljoscha Nern, Jennifer Colonell,
-    Oz Malkesman, Kei Ito, Stephan Saalfeld bioRxiv 376384; doi: doi:10.1101/376384
+    Jennifer Jeter, Geoffrey Meissner, Aljoscha Nern, Jennifer Colonell,
+    Oz Malkesman, Kei Ito, Stephan Saalfeld.
+    PLOS One; doi: https://doi.org/10.1371/journal.pone.0236495
 
     """
 
@@ -685,15 +691,101 @@ class _JRCVNC2018F(FlyTemplateBrain):
     ----------
     An unbiased template of the Drosophila brain and ventral nerve cord.
     John A Bogovic, Hideo Otsuna, Larissa Heinrich, Masayoshi Ito,
-    Jennifer Jeter, Geoffrey W Meissner, Aljoscha Nern, Jennifer Colonell,
-    Oz Malkesman, Kei Ito, Stephan Saalfeld bioRxiv 376384;
-    doi: doi:10.1101/376384
+    Jennifer Jeter, Geoffrey Meissner, Aljoscha Nern, Jennifer Colonell,
+    Oz Malkesman, Kei Ito, Stephan Saalfeld.
+    PLOS One; doi: https://doi.org/10.1371/journal.pone.0236495
 
     """
 
 JRCVNC2018F = _JRCVNC2018F(**template_meta['JRCVNC2018F'])
 
 
+class _JRCVNC2018M(FlyTemplateBrain):
+    """JRC2018 reference ventral nerve chords.
+
+    The JRCVNC2018M reference VNC is an average template VNC constructed from
+    VNCs labelled with brp-SNAP, dehydrated, and mounted in DPX and imaged at
+    0.19 x 0.19 x 0.38 microns. The image was downsampled to result in a 0.4
+    micron isotropic voxel size, which we take to be the standard JRCVNC2018F
+    space.
+
+    The JRCVNC2018U reference VNC was constructed as for JRCVNC2018F VNC but
+    pooling both male and female brains.
+
+    The JRCVNC2018M mesh, was generated in Amira from a 2 micron downsampled,
+    Lanczos filtered version of the respective template VNC. A surface was then
+    generated with a threshold level of 2800 and then smoothed and downsampled.
+
+    The JRCVNC2018U mesh, was generated in Amira from a 2 micron downsampled,
+    Lanczos filtered 8 bit version of the respective template VNC. A surface was
+    then generated with a threshold level of 20 and then smoothed and
+    downsampled.
+
+    Details
+    -------
+    For the VNC, Bogovic and Saalfeld used 36 female individuals (72 images
+    including left-right flips) for the female template, 39 male individuals
+    (78 image with left-right flips) for the male template, and the union of
+    both for the unisex brain template: 75 individuals (150 images with
+    left-right flips).
+
+    Downloaded from https://www.janelia.org/open-science/jrc-2018-brain-templates
+
+    References
+    ----------
+    An unbiased template of the Drosophila brain and ventral nerve cord.
+    John A Bogovic, Hideo Otsuna, Larissa Heinrich, Masayoshi Ito,
+    Jennifer Jeter, Geoffrey Meissner, Aljoscha Nern, Jennifer Colonell,
+    Oz Malkesman, Kei Ito, Stephan Saalfeld.
+    PLOS One; doi: https://doi.org/10.1371/journal.pone.0236495
+    """
+
+JRCVNC2018M = _JRCVNC2018M(**template_meta['JRCVNC2018M'])
+
+
+class _JRCVNC2018U(FlyTemplateBrain):
+    """JRC2018 reference ventral nerve chords.
+
+    The JRCVNC2018U reference VNC is an average template VNC constructed from
+    VNCs labelled with brp-SNAP, dehydrated, and mounted in DPX and imaged at
+    0.19 x 0.19 x 0.38 microns. The image was downsampled to result in a 0.4
+    micron isotropic voxel size, which we take to be the standard JRCVNC2018F
+    space.
+
+    The JRCVNC2018U reference VNC was constructed as for JRCVNC2018F/M VNCs but
+    pooling both male and female brains.
+
+    The JRCVNC2018F mesh, was generated in Amira from a 2 micron downsampled,
+    Lanczos filtered version of the respective template VNC. A surface was then
+    generated with a threshold level of 2800 and then smoothed and downsampled.
+
+    The JRCVNC2018U mesh, was generated in Amira from a 2 micron downsampled,
+    Lanczos filtered 8 bit version of the respective template VNC. A surface was
+    then generated with a threshold level of 20 and then smoothed and
+    downsampled.
+
+    Details
+    -------
+    For the VNC, Bogovic and Saalfeld used 36 female individuals (72 images
+    including left-right flips) for the female template, 39 male individuals
+    (78 image with left-right flips) for the male template, and the union of
+    both for the unisex brain template: 75 individuals (150 images with
+    left-right flips).
+
+    Downloaded from https://www.janelia.org/open-science/jrc-2018-brain-templates
+
+    References
+    ----------
+    An unbiased template of the Drosophila brain and ventral nerve cord.
+    John A Bogovic, Hideo Otsuna, Larissa Heinrich, Masayoshi Ito,
+    Jennifer Jeter, Geoffrey Meissner, Aljoscha Nern, Jennifer Colonell,
+    Oz Malkesman, Kei Ito, Stephan Saalfeld.
+    PLOS One; doi: https://doi.org/10.1371/journal.pone.0236495
+    """
+
+JRCVNC2018U = _JRCVNC2018U(**template_meta['JRCVNC2018U'])
+
+
 class _VNCIS1(FlyTemplateBrain):
     """VNCIS1 reference neuropil.
 
@@ -748,11 +840,96 @@ class _FAFB14(FlyTemplateBrain):
 FAFB14 = _FAFB14(**template_meta['FAFB14'])
 
 
+class _COURT2017VNS(FlyTemplateBrain):
+    """Female Adult Nervous System (NC82).
+
+    Original image provided by Wyatt Korff at Janelia Research Campus with a
+    neuropil background stain (NC82). The sample was adjusted to align with the
+    image axis.
+
+    References
+    ----------
+    Court RC.
+    Dissecting the ventral nervous system in Drosophila melanogaster
+    PhD Thesis 2017; http://hdl.handle.net/1842/25704
+
+    Robert Christopher Court, James Armstrong, Jana Börner, Gwyneth Card,
+    Marta Costa, Michael Dickinson, Carsten Duch, Wyatt Korff, Richard Mann,
+    David Merritt, Rod Murphey, Shigehiro Namiki, Andrew Seeds, David Shepherd,
+    Troy Shirangi, Julie Simpson, James Truman, John Tuthill, Darren Williams
+    A Systematic Nomenclature for the Drosophila Ventral Nervous System
+    biorxiv. 2017. doi: https://doi.org/10.1101/122952
+    """
+
+COURT2017VNS = _COURT2017VNS(**template_meta['COURT2017VNS'])
+
+
+class _COURT2018VNS(FlyTemplateBrain):
+    """Female Adult Nervous System.
+
+    A warped version of Court2017 to straighten the midline to make the template
+    symmetric (work done by Hideo Otsuna) leading to JRCVNC2018F.
+
+    References
+    ----------
+    Robert Court, Shigehiro Namiki, J Douglas Armstrong, Jana Börner, Gwyneth Card,
+    Marta Costa, Michael Dickinson, Carsten Duch, Wyatt Korff, Richard Mann,
+    David Merritt, Rod K Murphey, Andrew Seeds, Troy Shirangi, Julie H. Simpson,
+    James W Truman, John Tuthill, Darren Williams, David Shepherd
+    biorxiv. 2020. doi: https://doi.org/10.1101/122952
+
+    An unbiased template of the Drosophila brain and ventral nerve cord.
+    John A Bogovic, Hideo Otsuna, Larissa Heinrich, Masayoshi Ito,
+    Jennifer Jeter, Geoffrey Meissner, Aljoscha Nern, Jennifer Colonell,
+    Oz Malkesman, Kei Ito, Stephan Saalfeld.
+    PLOS One; doi: https://doi.org/10.1371/journal.pone.0236495
+    """
+
+COURT2018VNS = _COURT2018VNS(**template_meta['COURT2018VNS'])
+
+
+class _FANC(FlyTemplateBrain):
+    """Female Adult Nerve Cord
+
+    Using a serial-section electron microscopy (EM) to acquire a synapse-resolution
+    dataset containing the ventral nerve cord (VNC) of an adult female Drosophila melanogaster.
+
+    References
+    ----------
+    Reconstruction of motor control circuits in adult Drosophila using automated transmission electron microscopy
+    Jasper S Phelps, David Grant Colburn Hildebrand, Brett J Graham, Aaron T Kuan,
+    Logan A Thomas, Tri M Nguyen, Julia Buhmann, Anthony W Azevedo, Anne Sustar,
+    Sweta Agrawal, Mingguan Liu, Brendan L Shanny, Jan Funke, John C Tuthill,
+    Wei-Chung Allen Lee
+    Cell 2021 Feb 4;184(3):759-774.e18. doi: 10.1016/j.cell.2020.12.013.
+
+    """
+
+FANC = _FANC(**template_meta['FANC'])
+
+
+class _DmelL1CNS_Seymour(FlyTemplateBrain):
+    """L1 CNS ssTEM at 3.8x3.8x50 nm of whole Drosophila 1st instar larval CNS.
+
+    Imaged and assembled by Rick Fetter and Albert Cardona.
+
+    References
+    ----------
+    A multilevel multimodal circuit enhances action selection in Drosophila.
+    Ohyama, T., Schneider-Mizell, C., Fetter, R. et al. Nature 520, 633–639 (2015).
+    https://doi.org/10.1038/nature14297
+
+    """
+
+DmelL1CNS_Seymour = _DmelL1CNS_Seymour(**template_meta['Dmel-L1-CNS-Seymour'])
+
+
 def register_templates():
     """Register template brains with navis."""
     templates = [FCWB, IBN, IBNWB, IS2, JFRC2, T1, Dmel, DsecI, Dsim, Dvir,
                  JFRC2013, JFRC2013DS, JRC2018F, JRC2018U, JRCFIB2018F,
-                 JRCFIB2018Fraw, JRCVNC2018F, VNCIS1, FAFB14]
+                 JRCFIB2018Fraw, JRCVNC2018F, JRCVNC2018U, JRCVNC2018M, VNCIS1,
+                 FAFB14, FANC, DmelL1CNS_Seymour, COURT2017VNS, COURT2018VNS]
 
     for tmp in templates:
         transforms.registry.register_templatebrain(tmp, skip_existing=True)
